@@ -52,7 +52,7 @@ class PasswordMaker(object):
    worklist.append([ j for j in i.getObj().getKey(4) ])
   worklist2=[]
   for i in worklist:
-   worklist2.append(self.__vtableau.doEnc(self.__vtableau.doDec(self.__vtableau.doEnc(i[0],i[1]),i[2]),i[3]))
+   worklist2.append(self.__vtableau.doDec(self.__vtableau.doEnc(i[0],i[1]),self.__vtableau.doEnc(i[2],i[3])))
   returnStr1=''
   for i in worklist2:
    if returnStr1=='':
